"""arXiv base UI blueprint"""

from typing import Optional
from flask import Blueprint, Flask


class Base(object):
    """Attaches a base UI blueprint to an application."""

    def __init__(self, app: Optional[Flask] = None) -> None:
        """Initialize ``app`` with base blueprint."""
        if app is not None:
            self.init_app(app)

    def init_app(self, app: Flask) -> None:
        """Create and register the base UI blueprint."""
        blueprint = Blueprint(
            'baseui',
            __name__,
            template_folder='templates',
            static_folder='static',
            static_url_path=app.static_url_path + '/base',)
        app.register_blueprint(blueprint)



"""Provides routes for verifying baseui templates."""

from typing import Any, Tuple
from flask import Blueprint, render_template

from arxiv import status

blueprint = Blueprint('ui', __name__, url_prefix='')


@blueprint.route('/test', methods=['GET'])
def test_page() -> Tuple[dict, int, dict]:
    """Render the test page."""
    return render_template("base/base.html"), status.HTTP_200_OK, {}



"""Application factory for BaseUI app (development and testing only)."""

import logging
import os
from flask import Flask
from arxiv.base import Base, routes


def create_web_app() -> Flask:
    """Initialize and configure the base application."""
    app = Flask('base')
    basedir, _ = os.path.split(os.path.abspath(__file__))
    app.config.from_pyfile(os.path.join(basedir, 'config.py'))
    Base(app)    # Gives us access to the base UI templates and resources.
    app.register_blueprint(routes.blueprint)
    return app
